searchData={"items":[{"type":"module","title":"Supabase","doc":"The main entrypoint for the Supabase SDK library.","ref":"Supabase.html"},{"type":"module","title":"Installation - Supabase","doc":"The package can be installed by adding `supabase` to your list of dependencies in `mix.exs`:\n\n    def deps do\n      [\n        {:supabase_potion, \"~> 0.1\"}\n      ]\n    end","ref":"Supabase.html#module-installation"},{"type":"module","title":"Usage - Supabase","doc":"After installing `:supabase_potion`, you can easily and dynamically manage different `Supabase.Client`!","ref":"Supabase.html#module-usage"},{"type":"module","title":"Config - Supabase","doc":"The library offers a bunch of config options that can be used to control management of clients and other options.\n\n- `manage_clients` - whether to manage clients automatically, defaults to `true`\n\nYou can set up the library on your `config.exs`:\n\n    config :supabase, manage_clients: false","ref":"Supabase.html#module-config"},{"type":"module","title":"Clients - Supabase","doc":"A `Supabase.Client` is an Agent that holds general information about Supabase, that can be used to intereact with any of the children integrations, for example: `Supabase.Storage` or `Supabase.UI`.\n\nAlso a `Supabase.Client` holds a list of `Supabase.Connection` that can be used to perform operations on different buckets, for example.\n\n`Supabase.Client` is defined as:\n\n- `:name` - the name of the client, started by `start_link/1`\n- `:conn` - connection information, the only required option as it is vital to the `Supabase.Client`.\n  - `:base_url` - The base url of the Supabase API, it is usually in the form `https:// .supabase.io`.\n  - `:api_key` - The API key used to authenticate requests to the Supabase API.\n  - `:access_token` - Token with specific permissions to access the Supabase API, it is usually the same as the API key.\n- `:db` - default database options\n  - `:schema` - default schema to use, defaults to `\"public\"`\n- `:global` - global options config\n  - `:headers` - additional headers to use on each request\n- `:auth` - authentication options\n  - `:auto_refresh_token` - automatically refresh the token when it expires, defaults to `true`\n  - `:debug` - enable debug mode, defaults to `false`\n  - `:detect_session_in_url` - detect session in URL, defaults to `true`\n  - `:flow_type` - authentication flow type, defaults to `\"web\"`\n  - `:persist_session` - persist session, defaults to `true`\n  - `:storage` - storage type\n  - `:storage_key` - storage key","ref":"Supabase.html#module-clients"},{"type":"module","title":"Starting a Client - Supabase","doc":"You then can start a Client calling `Supabase.Client.start_link/1`:\n\n    iex> Supabase.Client.start_link(name: :my_client, client_info: %{db: %{schema: \"public\"}})\n    {:ok, #PID<0.123.0>}\n\nNotice that this way to start a Client is not recommended, since you will need to manage the `Supabase.Client` manually. Instead, you can use `Supabase.init_client!/1`, passing the Client options:\n\n    iex> Supabase.Client.init_client!(%{conn: %{base_url: \" \", api_key: \" \"}})\n    {:ok, #PID<0.123.0>}","ref":"Supabase.html#module-starting-a-client"},{"type":"module","title":"Acknowledgements - Supabase","doc":"This package represents the complete SDK for Supabase. That means\nthat it includes all of the functionality of the Supabase client integrations, as:\n\n- `Supabase.Fetcher`\n- `Supabase.Storage`\n- `supabase-postgrest` - TODO\n- `supabase-realtime` - TODO\n- `supabase-auth`- TODO\n- `supabase-ui` - TODO","ref":"Supabase.html#module-acknowledgements"},{"type":"module","title":"Supabase Storage - Supabase","doc":"Supabase Storage is a service for developers to store large objects like images, videos, and other files. It is a hosted object storage service, like AWS S3, but with a simple API and strong consistency.","ref":"Supabase.html#module-supabase-storage"},{"type":"module","title":"Supabase PostgREST - Supabase","doc":"PostgREST is a web server that turns your PostgreSQL database directly into a RESTful API. The structural constraints and permissions in the database determine the API endpoints and operations.","ref":"Supabase.html#module-supabase-postgrest"},{"type":"module","title":"Supabase Realtime - Supabase","doc":"Supabase Realtime provides a realtime websocket API powered by PostgreSQL notifications. It allows you to listen to changes in your database, and instantly receive updates as soon as they happen.","ref":"Supabase.html#module-supabase-realtime"},{"type":"module","title":"Supabase Auth - Supabase","doc":"Supabase Auth is a feature-complete user authentication system. It provides email & password sign in, email verification, password recovery, session management, and more, out of the box.","ref":"Supabase.html#module-supabase-auth"},{"type":"module","title":"Supabase UI - Supabase","doc":"Supabase UI is a set of UI components that help you quickly build Supabase-powered applications. It is built on top of Tailwind CSS and Headless UI, and is fully customizable. The package provides `Phoenix.LiveView` components!","ref":"Supabase.html#module-supabase-ui"},{"type":"module","title":"Supabase Fetcher - Supabase","doc":"Supabase Fetcher is a customized HTTP client for Supabase. Mainly used in Supabase Potion. If you want a complete control on how to make requests to any Supabase API, you would use this package directly.","ref":"Supabase.html#module-supabase-fetcher"},{"type":"function","title":"Supabase.init_client/1","doc":"","ref":"Supabase.html#init_client/1"},{"type":"function","title":"Supabase.init_client!/1","doc":"","ref":"Supabase.html#init_client!/1"},{"type":"function","title":"Supabase.schema/0","doc":"","ref":"Supabase.html#schema/0"},{"type":"module","title":"Supabase.Client","doc":"A client for interacting with Supabase. This module is responsible for\nmanaging the connection pool and the connection options.","ref":"Supabase.Client.html"},{"type":"module","title":"Usage - Supabase.Client","doc":"Usually you don't need to use this module directly, instead you should\nuse the `Supabase` module, available on `:supabase_potion` application.\n\nHowever, if you want to manage clients manually, you can leverage this\nmodule to start and stop clients dynamically. To start a single\nclient manually, you need to add it to your supervision tree:\n\n    defmodule MyApp.Application do\n      use Application\n\n      def start(_type, _args) do\n        children = [\n          {Supabase.Client, name: :supabase, client_info: %Supabase.Client{}}\n        ]\n\n        opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n        Supervisor.start_link(children, opts)\n      end\n    end\n\nNotice that starting a Client in this way, Client options will not be\nvalidated, so you need to make sure that the options are correct. Otherwise\napplication will crash.","ref":"Supabase.Client.html#module-usage"},{"type":"module","title":"Examples - Supabase.Client","doc":"iex> Supabase.Client.start_link(name: :supabase, client_info: client_info)\n    {:ok, #PID<0.123.0>}\n\n    iex> Supabase.Client.retrieve_client(:supabase)\n    %Supabase.Client{\n      name: :supabase,\n      conn: %{\n        base_url: \"https:// .supabase.io\",\n        api_key: \" \",\n        access_token: \" \"\n      },\n      db: %Supabase.Client.Db{\n        schema: \"public\"\n      },\n      global: %Supabase.Client.Global{\n        headers: %{}\n      },\n      auth: %Supabase.Client.Auth{\n        auto_refresh_token: true,\n        debug: false,\n        detect_session_in_url: true,\n        flow_type: :implicit,\n        persist_session: true,\n        storage: nil,\n        storage_key: \"sb- -auth-token\"\n      }\n    }\n\n    iex> Supabase.Client.retrieve_connection(:supabase)\n    %Supabase.Client.Conn{\n      base_url: \"https:// .supabase.io\",\n      api_key: \" \",\n      access_token: \" \"\n    }","ref":"Supabase.Client.html#module-examples"},{"type":"function","title":"Supabase.Client.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Supabase.Client.html#child_spec/1"},{"type":"macro","title":"Supabase.Client.is_client/1","doc":"","ref":"Supabase.Client.html#is_client/1"},{"type":"function","title":"Supabase.Client.parse/1","doc":"","ref":"Supabase.Client.html#parse/1"},{"type":"function","title":"Supabase.Client.parse!/1","doc":"","ref":"Supabase.Client.html#parse!/1"},{"type":"function","title":"Supabase.Client.retrieve_auth_url/2","doc":"","ref":"Supabase.Client.html#retrieve_auth_url/2"},{"type":"function","title":"Supabase.Client.retrieve_base_url/1","doc":"","ref":"Supabase.Client.html#retrieve_base_url/1"},{"type":"function","title":"Supabase.Client.retrieve_client/1","doc":"","ref":"Supabase.Client.html#retrieve_client/1"},{"type":"function","title":"Supabase.Client.retrieve_connection/1","doc":"","ref":"Supabase.Client.html#retrieve_connection/1"},{"type":"function","title":"Supabase.Client.retrieve_url/2","doc":"","ref":"Supabase.Client.html#retrieve_url/2"},{"type":"function","title":"Supabase.Client.start_link/1","doc":"","ref":"Supabase.Client.html#start_link/1"},{"type":"type","title":"Supabase.Client.client/0","doc":"","ref":"Supabase.Client.html#t:client/0"},{"type":"type","title":"Supabase.Client.params/0","doc":"","ref":"Supabase.Client.html#t:params/0"},{"type":"type","title":"Supabase.Client.t/0","doc":"","ref":"Supabase.Client.html#t:t/0"},{"type":"module","title":"Supabase.Client.Auth","doc":"Auth configuration schema. This schema is used to configure the auth\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Auth.html"},{"type":"module","title":"Fields - Supabase.Client.Auth","doc":"- `:auto_refresh_token` - Automatically refresh the token when it expires. Defaults to `true`.\n- `:debug` - Enable debug mode. Defaults to `false`.\n- `:detect_session_in_url` - Detect session in URL. Defaults to `true`.\n- `:flow_type` - Authentication flow type. Defaults to `\"implicit\"`.\n- `:persist_session` - Persist session. Defaults to `true`.\n- `:storage` - Storage type.\n- `:storage_key` - Storage key. Default to `\"sb-$host-auth-token\"` where $host is the hostname of your Supabase URL.\n\nFor more information about the auth options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing) and\n[auth guides](https://supabase.com/docs/guides/auth)","ref":"Supabase.Client.Auth.html#module-fields"},{"type":"function","title":"Supabase.Client.Auth.changeset/3","doc":"","ref":"Supabase.Client.Auth.html#changeset/3"},{"type":"type","title":"Supabase.Client.Auth.params/0","doc":"","ref":"Supabase.Client.Auth.html#t:params/0"},{"type":"type","title":"Supabase.Client.Auth.t/0","doc":"","ref":"Supabase.Client.Auth.html#t:t/0"},{"type":"behaviour","title":"Supabase.Client.Conn","doc":"Conn configuration for Supabase Client. This schema is used to configure\nthe connection options. This schema is embedded in the `Supabase.Client`.","ref":"Supabase.Client.Conn.html"},{"type":"behaviour","title":"Fields - Supabase.Client.Conn","doc":"- `:base_url` - The Supabase Project URL to use. This option is required.\n- `:api_key` - The Supabase ProjectAPI Key to use. This option is required.\n- `:access_token` - The access token to use. Default to the API key.\n\nFor more information about the connection options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing).","ref":"Supabase.Client.Conn.html#module-fields"},{"type":"function","title":"Supabase.Client.Conn.changeset/2","doc":"","ref":"Supabase.Client.Conn.html#changeset/2"},{"type":"callback","title":"Supabase.Client.Conn.changeset/2","doc":"","ref":"Supabase.Client.Conn.html#c:changeset/2"},{"type":"callback","title":"Supabase.Client.Conn.parse/1","doc":"","ref":"Supabase.Client.Conn.html#c:parse/1"},{"type":"opaque","title":"Supabase.Client.Conn.changeset/0","doc":"","ref":"Supabase.Client.Conn.html#t:changeset/0"},{"type":"type","title":"Supabase.Client.Conn.params/0","doc":"","ref":"Supabase.Client.Conn.html#t:params/0"},{"type":"type","title":"Supabase.Client.Conn.t/0","doc":"","ref":"Supabase.Client.Conn.html#t:t/0"},{"type":"module","title":"Supabase.Client.Db","doc":"DB configuration schema. This schema is used to configure the database\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Db.html"},{"type":"module","title":"Fields - Supabase.Client.Db","doc":"- `:schema` - The default schema to use. Defaults to `\"public\"`.\n\nFor more information about the database options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing) and\n[database guides](https://supabase.com/docs/guides/database).","ref":"Supabase.Client.Db.html#module-fields"},{"type":"function","title":"Supabase.Client.Db.changeset/2","doc":"","ref":"Supabase.Client.Db.html#changeset/2"},{"type":"type","title":"Supabase.Client.Db.params/0","doc":"","ref":"Supabase.Client.Db.html#t:params/0"},{"type":"type","title":"Supabase.Client.Db.t/0","doc":"","ref":"Supabase.Client.Db.html#t:t/0"},{"type":"module","title":"Supabase.Client.Global","doc":"Global configuration schema. This schema is used to configure the global\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Global.html"},{"type":"module","title":"Fields - Supabase.Client.Global","doc":"- `:headers` - The default headers to use in any Supabase request. Defaults to `%{}`.","ref":"Supabase.Client.Global.html#module-fields"},{"type":"function","title":"Supabase.Client.Global.changeset/2","doc":"","ref":"Supabase.Client.Global.html#changeset/2"},{"type":"type","title":"Supabase.Client.Global.params/0","doc":"","ref":"Supabase.Client.Global.html#t:params/0"},{"type":"type","title":"Supabase.Client.Global.t/0","doc":"","ref":"Supabase.Client.Global.html#t:t/0"},{"type":"module","title":"Supabase.ClientRegistry","doc":"Registry for the Supabase multiple Clients. This registry is used to\nregister and lookup the Supabase Clients defined by the user.\n\nThis Registry is used by the `Supabase.ClientSupervisor` to register and\nany `Supabase.Client` that is defined. That way, the `Supabase.ClientSupervisor`\ncan lookup the `Supabase.Client` by name and start it if it is not running.","ref":"Supabase.ClientRegistry.html"},{"type":"module","title":"Usage - Supabase.ClientRegistry","doc":"This Registry is used internally by the `Supabase.Application` and should\nstart automatically when the application starts.","ref":"Supabase.ClientRegistry.html#module-usage"},{"type":"function","title":"Supabase.ClientRegistry.child_spec/1","doc":"","ref":"Supabase.ClientRegistry.html#child_spec/1"},{"type":"function","title":"Supabase.ClientRegistry.lookup/1","doc":"","ref":"Supabase.ClientRegistry.html#lookup/1"},{"type":"function","title":"Supabase.ClientRegistry.named/1","doc":"","ref":"Supabase.ClientRegistry.html#named/1"},{"type":"function","title":"Supabase.ClientRegistry.register/1","doc":"","ref":"Supabase.ClientRegistry.html#register/1"},{"type":"function","title":"Supabase.ClientRegistry.start_link/1","doc":"","ref":"Supabase.ClientRegistry.html#start_link/1"},{"type":"module","title":"Supabase.ClientSupervisor","doc":"A supervisor for all Clients. In most cases this should be started\nautomatically by the application supervisor and be used mainly by\nthe `Supabase` module, available on `:supabase_potion` application.\n\nAlthough if you want to manage Clients manually, you can leverage\nthis module to start and stop Clients dynamically. To start the supervisor\nmanually, you need to add it to your supervision tree:\n\n    defmodule MyApp.Application do\n      use Application\n\n      def start(_type, _args) do\n        children = [\n          {Supabase.ClientSupervisor, []}\n        ]\n\n        opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n        Supervisor.start_link(children, opts)\n      end\n    end\n\nAnd then use the Supervisor to start custom clients:\n\n    iex> Supabase.ClientSupervisor.start_child({Supabase.Client, opts})\n    {:ok, #PID<0.123.0>}\n\nNotice that the Supabase Elixir SDK already starts a `Supabase.ClientSupervisor`\ninternally, so you don't need to start it manually. However, if you want to\nmanage clients manually, you can leverage this module to start and stop\nclients dynamically.\n\nTo manage manually the clients, you need to disable the internal management\ninto your application:\n\n    config :supabase, :manage_clients, false","ref":"Supabase.ClientSupervisor.html"},{"type":"function","title":"Supabase.ClientSupervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Supabase.ClientSupervisor.html#child_spec/1"},{"type":"function","title":"Supabase.ClientSupervisor.start_child/1","doc":"","ref":"Supabase.ClientSupervisor.html#start_child/1"},{"type":"function","title":"Supabase.ClientSupervisor.start_link/1","doc":"","ref":"Supabase.ClientSupervisor.html#start_link/1"},{"type":"module","title":"Supabase.Fetcher","doc":"A fundamental HTTP client for interfacing directly with Supabase services.\n\n`Supabase.Fetcher` provides the groundwork for sending HTTP requests to the Supabase infrastructure. This includes utilities for various HTTP methods such as GET, POST, PUT, DELETE, and functions to simplify the process of streaming data or uploading files.","ref":"Supabase.Fetcher.html"},{"type":"module","title":"Key Features - Supabase.Fetcher","doc":"- **Low-level HTTP Interactions**: This module allows for raw HTTP requests to any URL, simplifying interactions with web resources.\n- **Data Streaming**: Efficiently stream large data payloads, such as downloading files.\n- **Request Customization**: Extensive header customization and utility functions for constructing requests tailored to your requirements.\n- **Response Parsing**: Automatically converts JSON responses into Elixir maps and handles various response scenarios.","ref":"Supabase.Fetcher.html#module-key-features"},{"type":"module","title":"Recommended Usage - Supabase.Fetcher","doc":"While `Supabase.Fetcher` is versatile and comprehensive, it operates at a very granular level. For most applications and needs, leveraging higher-level APIs that correspond to specific Supabase services is advisable:\n\n- `Supabase.Storage` - API to interact directly with buckets and objects in Supabase Storage.","ref":"Supabase.Fetcher.html#module-recommended-usage"},{"type":"module","title":"Disclaimer - Supabase.Fetcher","doc":"If your aim is to directly harness this module as a low-level HTTP client, due to missing features in other packages or a desire to craft a unique Supabase integration, you can certainly do so. However, always keep in mind that `Supabase.Storage` and other Supabase-oriented packages might offer better abstractions and ease-of-use.\n\nUse `Supabase.Fetcher` with a clear understanding of its features and operations.","ref":"Supabase.Fetcher.html#module-disclaimer"},{"type":"function","title":"Supabase.Fetcher.apply_client_headers/3","doc":"","ref":"Supabase.Fetcher.html#apply_client_headers/3"},{"type":"function","title":"Supabase.Fetcher.apply_headers/3","doc":"Convenience function that given a `apikey` and a optional ` token`, it will return the headers\nto be used in a request to your Supabase API.","ref":"Supabase.Fetcher.html#apply_headers/3"},{"type":"function","title":"Examples - Supabase.Fetcher.apply_headers/3","doc":"iex> Supabase.Fetcher.apply_conn_headers(\"apikey-value\")\n     [{\"apikey\", \"apikey-value\"}, {\"authorization\", \"Bearer apikey-value\"}]\n\n     iex> Supabase.Fetcher.apply_conn_headers(\"apikey-value\", \"token-value\")\n     [{\"apikey\", \"apikey-value\"}, {\"authorization\", \"Bearer token-value\"}]","ref":"Supabase.Fetcher.html#apply_headers/3-examples"},{"type":"function","title":"Supabase.Fetcher.delete/3","doc":"Simple DELETE request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#delete/3"},{"type":"function","title":"Examples - Supabase.Fetcher.delete/3","doc":"iex> Supabase.Fetcher.delete(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}\n\n     iex> Supabase.Fetcher.delete(\"https://example.com\", %{key: \"value\"})\n     {:error, :not_found}","ref":"Supabase.Fetcher.html#delete/3-examples"},{"type":"function","title":"Supabase.Fetcher.format_response/1","doc":"","ref":"Supabase.Fetcher.html#format_response/1"},{"type":"function","title":"Supabase.Fetcher.get/1","doc":"Simple GET request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#get/1"},{"type":"function","title":"Examples - Supabase.Fetcher.get/1","doc":"iex> Supabase.Fetcher.get(\"https://example.com\")\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#get/1-examples"},{"type":"function","title":"Supabase.Fetcher.get/2","doc":"","ref":"Supabase.Fetcher.html#get/2"},{"type":"function","title":"Supabase.Fetcher.get/3","doc":"","ref":"Supabase.Fetcher.html#get/3"},{"type":"function","title":"Supabase.Fetcher.get_full_url/2","doc":"","ref":"Supabase.Fetcher.html#get_full_url/2"},{"type":"function","title":"Supabase.Fetcher.get_header/2","doc":"","ref":"Supabase.Fetcher.html#get_header/2"},{"type":"function","title":"Supabase.Fetcher.get_header/3","doc":"","ref":"Supabase.Fetcher.html#get_header/3"},{"type":"function","title":"Supabase.Fetcher.head/3","doc":"Simple HEAD request that format the response to a map or\nretrieve the error as `String.t()`","ref":"Supabase.Fetcher.html#head/3"},{"type":"function","title":"Supabase.Fetcher.new_connection/4","doc":"","ref":"Supabase.Fetcher.html#new_connection/4"},{"type":"function","title":"Supabase.Fetcher.patch/3","doc":"Simple PATCH request that format the response to a map or\nretrieve the error as `String.t()`","ref":"Supabase.Fetcher.html#patch/3"},{"type":"function","title":"Supabase.Fetcher.post/3","doc":"Simple POST request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#post/3"},{"type":"function","title":"Examples - Supabase.Fetcher.post/3","doc":"iex> Supabase.Fetcher.post(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#post/3-examples"},{"type":"function","title":"Supabase.Fetcher.put/3","doc":"Simple PUT request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#put/3"},{"type":"function","title":"Examples - Supabase.Fetcher.put/3","doc":"iex> Supabase.Fetcher.put(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#put/3-examples"},{"type":"function","title":"Supabase.Fetcher.stream/3","doc":"Makes a HTTP request to the desired URL, with default headers and\nstream back the response. Good to stream large files downlaods.\n\nYou can also pass custom `Finch` options directly to the underlying `Finch.stream/4` function.\nThose options can be seen on the [Finch documentation](https://hexdocs.pm/finch/Finch.html#stream/5-options).","ref":"Supabase.Fetcher.html#stream/3"},{"type":"function","title":"Examples - Supabase.Fetcher.stream/3","doc":"iex> {status, stream} = Supabase.Fetcher.stream(\"https://example.com\")\n     iex> file = File.stream!(\"path/to/file\", [], 4096)\n     Stream.run Stream.into(stream, file)","ref":"Supabase.Fetcher.html#stream/3-examples"},{"type":"function","title":"Supabase.Fetcher.upload/4","doc":"Upload a binary to the desired URL.\n\nparams:\n- `method`: `:put` or `:post`\n- `url`: the URL to upload the file\n- `file`: the path to the file to upload\n- `headers`: list of additional headers to append to the request","ref":"Supabase.Fetcher.html#upload/4"},{"type":"function","title":"Examples - Supabase.Fetcher.upload/4","doc":"iex> Supabase.Fetcher.upload(:post, \"https://example.com\", \"path/to/file\")\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#upload/4-examples"},{"type":"function","title":"Supabase.Fetcher.version/0","doc":"","ref":"Supabase.Fetcher.html#version/0"},{"type":"behaviour","title":"Supabase.FetcherBehaviour","doc":"Defines Supabase HTTP Clients callbacks","ref":"Supabase.FetcherBehaviour.html"},{"type":"callback","title":"Supabase.FetcherBehaviour.delete/3","doc":"","ref":"Supabase.FetcherBehaviour.html#c:delete/3"},{"type":"callback","title":"Supabase.FetcherBehaviour.get/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:get/4"},{"type":"callback","title":"Supabase.FetcherBehaviour.head/3","doc":"","ref":"Supabase.FetcherBehaviour.html#c:head/3"},{"type":"callback","title":"Supabase.FetcherBehaviour.patch/3","doc":"","ref":"Supabase.FetcherBehaviour.html#c:patch/3"},{"type":"callback","title":"Supabase.FetcherBehaviour.post/3","doc":"","ref":"Supabase.FetcherBehaviour.html#c:post/3"},{"type":"callback","title":"Supabase.FetcherBehaviour.put/3","doc":"","ref":"Supabase.FetcherBehaviour.html#c:put/3"},{"type":"callback","title":"Supabase.FetcherBehaviour.stream/3","doc":"","ref":"Supabase.FetcherBehaviour.html#c:stream/3"},{"type":"callback","title":"Supabase.FetcherBehaviour.upload/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:upload/4"},{"type":"type","title":"Supabase.FetcherBehaviour.body/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:body/0"},{"type":"type","title":"Supabase.FetcherBehaviour.headers/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:headers/0"},{"type":"type","title":"Supabase.FetcherBehaviour.method/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:method/0"},{"type":"type","title":"Supabase.FetcherBehaviour.reason/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:reason/0"},{"type":"type","title":"Supabase.FetcherBehaviour.response/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:response/0"},{"type":"type","title":"Supabase.FetcherBehaviour.result/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:result/0"},{"type":"type","title":"Supabase.FetcherBehaviour.url/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:url/0"},{"type":"module","title":"Supabase.Types.Atom","doc":"A custom type for Ecto that allows atoms to be used as fields in schemas.","ref":"Supabase.Types.Atom.html"},{"type":"exception","title":"Supabase.MissingSupabaseConfig","doc":"","ref":"Supabase.MissingSupabaseConfig.html"},{"type":"extras","title":"Supabase Potion","doc":"# Supabase Potion\n\nWhere the magic starts!","ref":"readme.html"},{"type":"extras","title":"Getting Started - Supabase Potion","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"Installation - Supabase Potion","doc":"To install the base SDK:\n\n```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.3\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Clients - Supabase Potion","doc":"A `Supabase.Client` is an Agent that holds general information about Supabase, that can be used to intereact with any of the children integrations, for example: `Supabase.Storage` or `Supabase.UI`.\n\n`Supabase.Client` is defined as:\n\n- `:name` - the name of the client, started by `start_link/1`\n- `:conn` - connection information, the only required option as it is vital to the `Supabase.Client`.\n    - `:base_url` - The base url of the Supabase API, it is usually in the form `https:// .supabase.io`.\n    - `:api_key` - The API key used to authenticate requests to the Supabase API.\n    - `:access_token` - Token with specific permissions to access the Supabase API, it is usually the same as the API key.\n- `:db` - default database options\n    - `:schema` - default schema to use, defaults to `\"public\"`\n- `:global` - global options config\n    - `:headers` - additional headers to use on each request\n- `:auth` - authentication options\n    - `:auto_refresh_token` - automatically refresh the token when it expires, defaults to `true`\n    - `:debug` - enable debug mode, defaults to `false`\n    - `:detect_session_in_url` - detect session in URL, defaults to `true`\n    - `:flow_type` - authentication flow type, defaults to `\"web\"`\n    - `:persist_session` - persist session, defaults to `true`\n    - `:storage` - storage type\n    - `:storage_key` - storage key","ref":"readme.html#clients"},{"type":"extras","title":"Usage - Supabase Potion","doc":"The Supabase Elixir SDK provides a flexible way to manage `Supabase.Client` instances, which can, in turn, manage multiple `Supabase.Client` instances. Here's a brief overview of the key concepts:","ref":"readme.html#usage"},{"type":"extras","title":"Starting a Client - Supabase Potion","doc":"You can start a client using the `Supabase.Client.start_link/1` function. However, it's recommended to use `Supabase.init_client!/1`, which allows you to pass client options and automatically manage `Supabase.Client` processes.\n\n```elixir\niex> Supabase.Client.init_client!(%{conn: %{base_url: \" \", api_key: \" \"}})\n{:ok, #PID<0.123.0>}\n```","ref":"readme.html#starting-a-client"},{"type":"extras","title":"Configuration - Supabase Potion","doc":"Ensure your Supabase configurations are set:\n\n```elixir\nimport Config\n\nconfig :supabase,\n  manage_clients: false,\n  supabase_base_url: System.fetch_env!(\"SUPABASE_BASE_URL\"),\n  supabase_api_key: System.fetch_env!(\"SUPABASE_API_KEY\"),\n```\n\n- `supabase_base_url`: The base URL of your Supabase project! More information on how to find it can be seen on the [next section](#how-to-find-my-supabase-base-url?)\n- `supabase_api_key`: The secret of your Supabase project! More information on how to find it can be seen on the [next section](#how-to-find-my-supabase-api-key?)\n- `manage_clients`: Enable or disable the internal client management by the library. Defauls to `true`, see more on the [library supervisor documentation](https://hexdocs.pm/supabase_potion/Supabase.ClientSupervisor.html).\n\nMake sure to set the environment variables `SUPABASE_BASE_URL` and `SUPABASE_API_KEY`.","ref":"readme.html#configuration"},{"type":"extras","title":"How to find my Supabase base URL? - Supabase Potion","doc":"You can find your Supabase base URL in the Settings page of your project.\nFirstly select your project from the initial Dashboard.\nOn the left sidebar, click on the Settings icon, then select API.\nThe base URL is the first field on the page.","ref":"readme.html#how-to-find-my-supabase-base-url"},{"type":"extras","title":"How to find my Supabase API Key? - Supabase Potion","doc":"You can find your Supabase API key in the Settings page of your project.\nFirstly select your project from the initial Dashboard.\nOn the left sidebar, click on the Settings icon, then select API.\nThe API key is the second field on the page.\n\nThere two types of API keys, the public and the private. The last one\nbypass any Row Level Security (RLS) rules you have set up.\nSo you shouldn't use it in your frontend application.\n\nIf you don't know what RLS is, you can read more about it here:\nhttps://supabase.com/docs/guides/auth/row-level-security\n\nFor most cases you should prefer to use the public \"anon\" Key.","ref":"readme.html#how-to-find-my-supabase-api-key"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}